@@ -16,6 +16,8 @@
 
 #include <seqan/sequence.h>
 #include <seqan/stream.h>
+#include <seqan/seq_io/guess_stream_format.h> // had to add these 2 lines for it to compile with latest
+#include <seqan/seq_io/read_fasta_fastq.h>    // svn trunk: rev12932
 
 #include <fstream>
 
@@ -174,7 +176,7 @@ int
 main( int argc, char * argv[] ) {
 
 	//const char * fasta_filename = "/home/john/Data/MEIS1/meis1-peaks.fasta";
-	const char * fasta_filename = "/home/john/Dev/MyProjects/STEME/python/stempy/test/fasta/T00759-tiny.fa";
+	const char * fasta_filename = "/home/john/Dev/STEME/python/stempy/test/fasta/T00759-tiny.fa";
 	if( argc > 1 ) {
 		fasta_filename = argv[ 1 ];
 	}
