@@ -51,21 +51,30 @@ def job_url(uuid):
     return 'result/%s/STEME.html' % uuid
 
 
+def job_log_url(uuid):
+    """
+    The URL for a job.
+    """
+    return 'result/%s/steme.log' % uuid
+
+
+
 def named_job(job, link=True):
     """
     Return some markup that refers to a job.
     """
-    if not link:
-        if job.name:
-            return Markup('Job "%s"' % job.name)
-        else:
-            return Markup('Unnamed job')
-    else:
+    html = job_file(job.uuid, 'STEME.html')
+    if link and os.path.exists(html) and os.stat(html).st_size > 0:
         url = job_url(job.uuid)
         if job.name:
             return Markup('Job <a href="%s">%s</a>' % (url, job.name))
         else:
             return Markup('Unnamed <a href="%s">job</a>' % url)
+    else:
+        if job.name:
+            return Markup('Job "%s"' % job.name)
+        else:
+            return Markup('Unnamed job')
 
 
 def check_jobs_finished():
@@ -98,6 +107,25 @@ def check_jobs_finished():
     db.session.commit()
 
 
+
+
+def check_job_successful(job):
+    """
+    Check that the job finished successfully.
+    """
+    job_dir = job_file(job.uuid)
+    html = job_file(job.uuid, 'STEME.html')
+    meme = job_file(job.uuid, 'meme.txt')
+    successful = (
+        os.path.exists(job_dir)
+        and os.path.exists(html)
+        and os.stat(html).st_size # non-empty HTML
+        and os.path.exists(meme)
+    )
+    return successful
+
+
+
 def run_steme(form, job):
     """
     Run the STEME algorithm.
@@ -140,7 +168,8 @@ def run_steme(form, job):
     args = map(str, args) # convert to strings
     logger.info('Starting STEME job %s with args: %s', job.uuid, ' '.join(('"%s"' % a) for a in args))
     stdout = open(job_file(job.uuid, 'STEME.out'), 'w')
-    os.environ['PYTHONPATH'] = app.config['PYTHONPATH']
+    if 'PYTHONPATH' in app.config:
+        os.environ['PYTHONPATH'] = app.config['PYTHONPATH']
     popen = subprocess.Popen(
         args, 
         bufsize=-1, 
@@ -188,7 +217,13 @@ def list_jobs():
     The list jobs view.
     """
     check_jobs_finished()
-    return render_template("listjobs.html", jobs=Job.query.order_by(desc(Job.creation_date)).all(), named_job=named_job)
+    return render_template(
+        "listjobs.html", 
+        jobs=Job.query.order_by(desc(Job.creation_date)).all(), 
+        named_job=named_job,
+        check_job_successful=check_job_successful,
+        job_log_url=job_log_url,
+    )
 
 
 
