@@ -2027,21 +2027,33 @@ class Algorithm(object):
 #            raise RuntimeError(record)
 #        file_handler.handleError = handleError
 
-    
-    def _load_sequences(self, fasta):
-        "Read the sequences and build STEME object from index."
-        self.input_sequences = SequenceSet(fasta, self.options)
-        if not self.options.max_num_sites:
-            # allow number of sites up to 3 * # sequences / 2, with hard limit of 10000 if not user-specified
+
+    def _set_min_and_max_number_sites(self):
+        "Configure our max and min number of sites options if user has not set them explicitly."
+        if not self.options.max_num_sites:            
+            # allow number of sites up to 3 * # sequences / 2, with a hard limit if not user-specified
             hard_limit = 10000
             self.options.max_num_sites = min(3 * len(self.input_sequences.seqs) / 2, hard_limit)
             if hard_limit == self.options.max_num_sites:
-                logger.warning('Hit cap of %d on maximum # sites, user can over-ride this with the --max-sites option. High values will slow STEME down.' % hard_limit)
-            logger.info('Set maximum number of sites to %d', self.options.max_num_sites)
+                logger.warning('Hit cap of %d on maximum number of sites, user can over-ride this with the --max-sites option. High values will slow STEME down.' % hard_limit)
+            
+            # however if user has set minimum number of sites always have at least 50% more
+            if self.options.min_num_sites:
+                twice = 2 * self.options.min_num_sites
+                if self.options.max_num_sites < twice:
+                    self.options.max_num_sites = twice
+                    logger.info('Maximum number of sites not explicitly set and is less than twice minimum. Increasing to %d', self.options.max_num_sites)
+                
+            logger.info('Maximum number of sites not explicitly set. Was set to %d', self.options.max_num_sites)
+            
         if not self.options.min_num_sites:
-            # always look for at least 2 sites unless max_num_sites is small
+            # Look for at least one site in every 10th sequence
+            # but always look for at least 2 sites unless max_num_sites is small
             self.options.min_num_sites = max(len(self.input_sequences.seqs) / 10, min(2, self.options.max_num_sites))
-            logger.info('Set minimum number of sites to %d', self.options.min_num_sites)
+            logger.info('Minimum number of sites not explicitly set. Was set to %d', self.options.min_num_sites)
+
+        if self.options.min_num_sites > self.options.max_num_sites:
+            raise RuntimeError('Bad configuration options: Minimum number of sites should be less than maximum number of sites.')
         
         
     def _initialise_bg(self):
@@ -2123,7 +2135,8 @@ class Algorithm(object):
             #
             with Timer(msg='load sequences') as _timer:
                 self.fasta = fasta
-                self._load_sequences(fasta)
+                self.input_sequences = SequenceSet(fasta, self.options)
+                self._set_min_and_max_number_sites()
             
             #
             # Calculate the background frequencies and likelihoods
