@@ -8,7 +8,7 @@ HTML output.
 """
 
 import os, shutil, logging
-from . import ensure_dir_exists, OptionParser, add_options, get_default_options, __version__
+from . import ensure_dir_exists, OptionParser, add_options, get_default_options, __release__
 from jinja2 import Environment, PackageLoader
 from datetime import datetime, timedelta
 
@@ -112,7 +112,7 @@ class HTMLOutput(object):
             'calc_rel_enrichment' : calc_rel_enrichment,
             'timings' : algorithm.timings,
             'total_duration' : algorithm.total_duration,
-            'version' : __version__,
+            'version' : __release__,
             'completion_date_time' : datetime.now().strftime('%c'),
             'total_duration_string' : time_delta_readable(algorithm.total_duration)
         }
